pub struct AiCallLog { /* private fields */ }Expand description
Bounded ring buffer of AiCallRecords.
Implementations
Sourceimpl AiCallLog
impl AiCallLog
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
Create a log retaining at most capacity of the most recent records.
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create a log with a default capacity of 10,000 records.
Sourcepub fn record(&self, record: AiCallRecord)
pub fn record(&self, record: AiCallRecord)
Append a record, evicting the oldest if at capacity.
Sourcepub fn snapshot(&self) -> Vec<AiCallRecord>
pub fn snapshot(&self) -> Vec<AiCallRecord>
Snapshot the retained records, oldest first. Backs laminar.ai_calls.
Sourcepub fn total_recorded(&self) -> u64
pub fn total_recorded(&self) -> u64
Total calls ever logged, including those evicted from the buffer.